/*
 * Copyright (C) 2019  Magnus Bergman <magnus@snisurset.net>
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, see <http:/www.gnu.org/licenses/>
 */
#include <stdint.h>                     /* uint8_t, uint16_t */
#include <stdlib.h>                     /* malloc() */
#include <string.h>                     /* strncmp() */

#include "sauce.h"

#define SAUCE_OFFSET_ID 0
#define SAUCE_OFFSET_Version 5
#define SAUCE_OFFSET_Title 7
#define SAUCE_OFFSET_Author 42
#define SAUCE_OFFSET_Group 62
#define SAUCE_OFFSET_Date 82
#define SAUCE_OFFSET_FileSize 90
#define SAUCE_OFFSET_DataType 94
#define SAUCE_OFFSET_FileType 95
#define SAUCE_OFFSET_TInfo1 96
#define SAUCE_OFFSET_TInfo2 98
#define SAUCE_OFFSET_TInfo3 100
#define SAUCE_OFFSET_TInfo4 102
#define SAUCE_OFFSET_Comments 104
#define SAUCE_OFFSET_TFlags 105
#define SAUCE_OFFSET_TInfoS 106

#define get8(p) (*(uint8_t*)(p))
#define get16(p) le16toh(*(uint16_t*)(p))
#define get32(p) le32toh(*(uint32_t*)(p))

sauce_t *
sauce_buffer_validate(sauce_buffer_t* buffer,sauce_t *sauce)
{
    unsigned char *p;
    if(buffer->size<128)
        return NULL;
    p = buffer->buffer+buffer->size-128;
    if(strncmp((char*)p+SAUCE_OFFSET_ID,"SAUCE",5))
        return NULL;
    if(!sauce)
        sauce = (sauce_t*)malloc(sizeof(sauce_t));
    sauce->FileSize = get32(p+SAUCE_OFFSET_FileSize);
    sauce->DataType = p[SAUCE_OFFSET_DataType];
    sauce->FileType = p[SAUCE_OFFSET_FileType];
    sauce->TInfo[0] = get16(p+SAUCE_OFFSET_TInfo1);
    sauce->TInfo[1] = get16(p+SAUCE_OFFSET_TInfo2);
    sauce->TInfo[2] = get16(p+SAUCE_OFFSET_TInfo3);
    sauce->TInfo[3] = get16(p+SAUCE_OFFSET_TInfo4);
    sauce->TFlags = get8(p+SAUCE_OFFSET_TFlags);
    return sauce;
}
