/*
 * Copyright (C) 2018 - 2019  Magnus Bergman <magnus@snisurset.net>
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, see <http:/www.gnu.org/licenses/>
 */
#include <cairo-svg.h>
#include <stdlib.h>
#include <string.h>

#include "abydos.h"

/**
 * SECTION: abydos-util
 * @short_description: A few conveniency functions.
 * @title: Utility
 * @include: abydos.h
 **/


abydos_t *
abydos_create_from_file(const char *mime_type, const char *filename)
{
    abydos_t *ar = abydos_create(mime_type);
    if(!ar)
        return NULL;
    if(abydos_from_file(ar,filename) < 0){
        abydos_destroy(ar);
        return NULL;
    }
    return ar;
}


cairo_surface_t *
abydos_load(const char *mime_type, const char *filename)
{
    abydos_t *ar;
    cairo_surface_t *surface;
    if(!strcasecmp(mime_type,"image/png"))
        return cairo_image_surface_create_from_png (filename);
    ar = abydos_create_from_file(mime_type, filename);
    if(!ar)
        return NULL;
    surface = abydos_get_image_surface(ar, ABYDOS_GROW_TO_ASPECT_RATIO);
    abydos_destroy(ar);
    return surface;
}


cairo_status_t
abydos_write_to_png(abydos_t *ar, const char *filename)
{
    cairo_surface_t *surface = abydos_get_image_surface(ar,0);
    cairo_surface_write_to_png(surface,filename);
    cairo_surface_destroy(surface);
    return 0;
}


cairo_status_t
abydos_write_to_svg(abydos_t *ar, const char *filename)
{
    abydos_info_t info;
    cairo_surface_t *surface;
    cairo_t *cr;
    abydos_get_info(ar,&info);
    surface = cairo_svg_surface_create(filename,info.width,info.height);
    cr = cairo_create(surface);
    abydos_render(ar,cr,0);
    cairo_destroy(cr);
    cairo_surface_destroy(surface);
    return 0;
}


cairo_bool_t
abydos_can_animate(abydos_t *ar)
{
    abydos_info_t info;
    if(abydos_get_frame_count(ar) > 1)
        return 1;
    abydos_get_info(ar, &info);
    return info.features & ABYDOS_FEATURE_SCALABLE_TIME ? 1 : 0;
}
